@@ -1,11 +1,13 @@
 /***************************************************************************
- *   copyright       : (C) 2009-2019 by Pascal Brachet                     *
+ *   copyright       : (C) 2009-2021 by Pascal Brachet                     *
+ *   https://www.xm1math.net/algobox/                                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #include "algoeditor.h"
@@ -26,8 +28,13 @@
 #include <QModelIndex>
 #include <QAbstractItemModel>
 #include <QScrollBar>
-#include <QTextCodec>
 #include <QFile>
+#include <QRegularExpression>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    #include <QtCore/QTextCodec>
+#else
+    #include <QtCore5Compat/QTextCodec>
+#endif
 #include "blockdata.h"
 
 AlgoEditor::AlgoEditor(QWidget *parent,QFont & efont): QTextEdit(parent),c(0)
@@ -42,7 +49,11 @@ setFrameShape(QFrame::NoFrame);
 for (int i = 0; i < 3; ++i) UserBookmark[i]=0;
 encoding="";
 setFont(efont);
+#if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
 setTabStopWidth(fontMetrics().width("  "));
+#else
+setTabStopDistance(fontMetrics().horizontalAdvance("  "));
+#endif
 setTabChangesFocus(false);
 highlighter = new AlgoHighlighter(document());
 setWordWrapMode(QTextOption::NoWrap);
@@ -120,7 +131,7 @@ delete menu;
 
 bool AlgoEditor::search( const QString &expr, bool cs, bool wo, bool forward, bool startAtCursor )
 {
-QTextDocument::FindFlags flags = 0;
+QTextDocument::FindFlags flags = QTextDocument::FindFlags(0);
 if (cs) flags |= QTextDocument::FindCaseSensitively;
 if (wo) flags |= QTextDocument::FindWholeWords;
 QTextCursor c = textCursor();
@@ -345,10 +356,10 @@ if ( e->key()==Qt::Key_Tab)
     if (block.isValid()) 
 	{
 	QString txt=block.text();
-	if (txt.contains(QString(0x2022)))
+	if (txt.contains(QString(QChar(0x2022))))
 	    {
 	    //e->ignore();
-	    search(QString(0x2022) ,true,true,true,true);
+	    search(QString(QChar(0x2022)) ,true,true,true,true);
 	    return;		
 	    }
 	}
@@ -361,10 +372,10 @@ else if ( e->key()==Qt::Key_Backtab)
     if (block.isValid()) 
 	{
 	QString txt=block.text();
-	if (txt.contains(QString(0x2022)))
+	if (txt.contains(QString(QChar(0x2022))))
 	    {
 	    //e->ignore();
-	    search(QString(0x2022) ,true,true,false,true);
+	    search(QString(QChar(0x2022)) ,true,true,false,true);
 	    return;		
 	    }
 	}
@@ -470,14 +481,15 @@ tc.movePosition(QTextCursor::PreviousCharacter,QTextCursor::KeepAnchor, textUnde
 tc.removeSelectedText();
 int pos=tc.position();
 QString insert_word = completion;
-QRegExp rbb("DEBUT_([A-Za-z_]+)");
-if (completion.contains(rbb)) 
+QRegularExpression rbb("DEBUT_([A-Za-z_]+)");
+QRegularExpressionMatch rbbMatch=rbb.match(completion);
+if (rbbMatch.hasMatch())
 	{
 	insert_word="\t"+insert_word;
 	tc.insertText(insert_word);
 	insertNewLine();
 	insertNewLine();
-	tc.insertText("FIN_"+rbb.cap(1));
+	tc.insertText("FIN_"+rbbMatch.captured(1));
 	tc.movePosition(QTextCursor::Up,QTextCursor::MoveAnchor,1);
 	setTextCursor(tc);
 	}
@@ -486,7 +498,7 @@ else
 	tc.insertText(insert_word);
 	tc.setPosition(pos,QTextCursor::MoveAnchor);
 	setTextCursor(tc);
-	if (!search(QString(0x2022) ,true,true,true,true))
+	if (!search(QString(QChar(0x2022)) ,true,true,true,true))
 	  {
 	  tc.setPosition(pos+completion.length(),QTextCursor::MoveAnchor);
 	  setTextCursor(tc);
