@@ -1,11 +1,13 @@
 /***************************************************************************
- *   copyright       : (C) 2009-2019 by Pascal Brachet                     *
+ *   copyright       : (C) 2009-2021 by Pascal Brachet                     *
+ *   https://www.xm1math.net/algobox/                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #include "jseditor.h"
@@ -42,12 +44,15 @@ setFrameShape(QFrame::NoFrame);
 for (int i = 0; i < 3; ++i) UserBookmark[i]=0;
 encoding="";
 setFont(efont);
-setTabStopWidth(fontMetrics().width("  "));
 setTabChangesFocus(false);
 highlighter = new JSHighlighter(document());
 setWordWrapMode(QTextOption::WordWrap);
 setCursorWidth(2);
+#if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
 setTabStopWidth(fontMetrics().width("  "));
+#else
+setTabStopDistance(fontMetrics().horizontalAdvance("  "));
+#endif
 connect(this, SIGNAL(cursorPositionChanged()), this, SLOT(matchAll()));
 setFocus();
 }
@@ -121,7 +126,7 @@ delete menu;
 
 bool JSEditor::search( const QString &expr, bool cs, bool wo, bool forward, bool startAtCursor )
 {
-QTextDocument::FindFlags flags = 0;
+QTextDocument::FindFlags flags = QTextDocument::FindFlags(0);
 if (cs) flags |= QTextDocument::FindCaseSensitively;
 if (wo) flags |= QTextDocument::FindWholeWords;
 QTextCursor c = textCursor();
@@ -331,10 +336,10 @@ if ( e->key()==Qt::Key_Tab)
     if (block.isValid()) 
 	{
 	QString txt=block.text();
-	if (txt.contains(QString(0x2022)))
+	if (txt.contains(QString(QChar(0x2022))))
 	    {
 	    //e->ignore();
-	    search(QString(0x2022) ,true,true,true,true);
+	    search(QString(QChar(0x2022)) ,true,true,true,true);
 	    return;		
 	    }
 	}
@@ -347,10 +352,10 @@ else if ( e->key()==Qt::Key_Backtab)
     if (block.isValid()) 
 	{
 	QString txt=block.text();
-	if (txt.contains(QString(0x2022)))
+	if (txt.contains(QString(QChar(0x2022))))
 	    {
 	    //e->ignore();
-	    search(QString(0x2022) ,true,true,false,true);
+	    search(QString(QChar(0x2022)) ,true,true,false,true);
 	    return;		
 	    }
 	}
